==> webauthn4j-core-0.21.5.RELEASE-sources.jar: com/webauthn4j/data/extension/authenticator/HMACSecretAuthenticationExtensionAuthenticatorInput.java <==
/*
 * Copyright 2002-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.webauthn4j.data.extension.authenticator;

import com.webauthn4j.data.extension.SingleValueExtensionInputBase;
import com.webauthn4j.validator.exception.ConstraintViolationException;
import org.checkerframework.checker.nullness.qual.NonNull;

public class HMACSecretAuthenticationExtensionAuthenticatorInput extends SingleValueExtensionInputBase<HMACGetSecretAuthenticatorInput> implements AuthenticationExtensionAuthenticatorInput{

    public static final String ID = "hmac-secret";
    public static final String KEY_HMAC_SECRET = "hmac-secret";

    public HMACSecretAuthenticationExtensionAuthenticatorInput(@NonNull HMACGetSecretAuthenticatorInput value) {
        super(value);
    }

    @Override
    public @NonNull String getIdentifier() {
        return ID;
    }

    @SuppressWarnings({"ConstantConditions", "java:S2583"})
    @Override
    public void validate() {
        // value can be null when deserialized by Jackson
        if (getValue() == null) {
            throw new ConstraintViolationException("value must not be null");
        }
        // value can be null when deserialized by Jackson
        if (getValue().getKeyAgreement() == null) {
            throw new ConstraintViolationException("keyAgreement must not be null");
        }
        if (getValue().getSaltAuth() == null) {
            throw new ConstraintViolationException("saltAuth must not be null");
        }
        if (getValue().getSaltEnc() == null) {
            throw new ConstraintViolationException("saltEnc must not be null");
        }
        if (getValue().getSaltAuth().length != 32) {
            throw new ConstraintViolationException("saltAuth must be 32 bytes length");
        }
        if (getValue().getSaltEnc().length != 32) {
            throw new ConstraintViolationException("saltEnc must be 32 bytes length");
        }
    }
}

==> webauthn4j-core-0.24.0.RELEASE-sources.jar: com/webauthn4j/data/extension/authenticator/HMACSecretAuthenticationExtensionAuthenticatorInput.java <==
/*
 * Copyright 2002-2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.webauthn4j.data.extension.authenticator;

import com.webauthn4j.data.extension.SingleValueExtensionInputBase;
import com.webauthn4j.validator.exception.ConstraintViolationException;
import org.jetbrains.annotations.NotNull;

public class HMACSecretAuthenticationExtensionAuthenticatorInput extends SingleValueExtensionInputBase<HMACGetSecretAuthenticatorInput> implements AuthenticationExtensionAuthenticatorInput{

    public static final String ID = "hmac-secret";
    public static final String KEY_HMAC_SECRET = "hmac-secret";

    public HMACSecretAuthenticationExtensionAuthenticatorInput(@NotNull HMACGetSecretAuthenticatorInput value) {
        super(value);
    }

    @Override
    public @NotNull String getIdentifier() {
        return ID;
    }

    @SuppressWarnings({"ConstantConditions", "java:S2583"})
    @Override
    public void validate() {
        // value can be null when deserialized by Jackson
        if (getValue() == null) {
            throw new ConstraintViolationException("value must not be null");
        }
        // value can be null when deserialized by Jackson
        if (getValue().getKeyAgreement() == null) {
            throw new ConstraintViolationException("keyAgreement must not be null");
        }
        if (getValue().getSaltAuth() == null) {
            throw new ConstraintViolationException("saltAuth must not be null");
        }
        if (getValue().getSaltEnc() == null) {
            throw new ConstraintViolationException("saltEnc must not be null");
        }
        if (getValue().getSaltAuth().length != 32) {
            throw new ConstraintViolationException("saltAuth must be 32 bytes length");
        }
        if (getValue().getSaltEnc().length != 32) {
            throw new ConstraintViolationException("saltEnc must be 32 bytes length");
        }
    }
}
